@@ -10,7 +10,7 @@
 #
 #
 # IDENTIFICATION
-#    $Header: /usr/local/cvsroot/postgres95/src/backend/catalog/genbki.sh,v 1.1.1.1 1996/07/09 06:21:15 scrappy Exp $
+#    $Header: /usr/local/cvsroot/postgres95/src/backend/catalog/genbki.sh,v 1.1.1.1.2.5 1996/08/24 20:38:13 scrappy Exp $
 #
 # NOTES
 #    non-essential whitespace is removed from the generated file.
@@ -58,8 +58,11 @@ done
 cat $SYSFILES | \
 sed -e 's/\/\*.*\*\///g' \
     -e 's/;[ 	]*$//g'  \
+    -e 's/^[ 	]*//' \
     -e 's/\ Oid/\ oid/g' \
     -e 's/\ NameData/\ name/g' \
+    -e 's/^Oid/oid/g' \
+    -e 's/^NameData/\name/g' \
     -e 's/(NameData/(name/g' \
     -e 's/(Oid/(oid/g' | \
 awk '
@@ -78,8 +81,21 @@ BEGIN {
 	bootstrap = 0;
 	nc = 0;
 	reln_open = 0;
+        comment_level = 0;
 }
 
+# ----------------
+# Anything in a /* .. */ block should be ignored.
+# Blank lines also go.
+# Note that any /* */ comment on a line by itself was removed from the line
+# by the sed above.
+# ----------------
+/^\/\*/           { comment_level += 1; next; }
+/^\*\//           { comment_level -= 1; next; }
+comment_level > 0 { next; }
+
+/^[ 	]*$/      { next; }
+
 # ----------------
 #	anything in a BKI_BEGIN .. BKI_END block should be passed
 #	along without interpretation.
