@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *    $Header: /usr/local/devel/pglite/cvs/src/backend/storage/lmgr/lock.c,v 1.6 1996/02/24 00:41:09 jolly Exp $
+ *    $Header: /usr/local/cvsroot/postgres95/src/backend/storage/lmgr/lock.c,v 1.2 1996/07/30 07:47:33 scrappy Exp $
  *
  * NOTES
  *    Outside modules can create a lock table and acquire/release
@@ -102,12 +102,6 @@ static MASK	BITS_ON[MAX_LOCKTYPES];
  */
 static bool LockingIsDisabled;
 
-/* ------------------
- * from storage/ipc/shmem.c
- * ------------------
- */
-extern HTAB *ShmemInitHash();
-
 /* -------------------
  * map from tableId to the lock table structure
  * -------------------
