@@ -7,7 +7,7 @@
  *
  *
  * IDENTIFICATION
- *    $Header: /usr/local/devel/pglite/cvs/src/backend/storage/lmgr/proc.c,v 1.11 1996/02/24 00:41:10 jolly Exp $
+ *    $Header: /usr/local/cvsroot/postgres95/src/backend/storage/lmgr/proc.c,v 1.5 1996/08/01 05:11:33 scrappy Exp $
  *
  *-------------------------------------------------------------------------
  */
@@ -46,7 +46,7 @@
  *      This is so that we can support more backends. (system-wide semaphore
  *      sets run out pretty fast.)                -ay 4/95
  *
- * $Header: /usr/local/devel/pglite/cvs/src/backend/storage/lmgr/proc.c,v 1.11 1996/02/24 00:41:10 jolly Exp $
+ * $Header: /usr/local/cvsroot/postgres95/src/backend/storage/lmgr/proc.c,v 1.5 1996/08/01 05:11:33 scrappy Exp $
  */
 #include <sys/time.h>
 #ifndef WIN32
@@ -56,15 +56,6 @@
 #include <sys/types.h>
 #include "libpq/pqsignal.h"	/* substitute for <signal.h> */
 
-#if defined(PORTNAME_bsdi)
-/* hacka, hacka, hacka (XXX) */
-union semun {
-	int val; /* value for SETVAL */
-	struct semid_ds *buf; /* buffer for IPC_STAT & IPC_SET */
-	ushort *array; /* array for GETALL & SETALL */
-};
-#endif
-
 #include "access/xact.h"
 #include "utils/hsearch.h"
 #include "utils/elog.h"
@@ -104,11 +95,6 @@ PROC 	*MyProc = NULL;
 static void ProcKill(int exitStatus, int pid);
 static void ProcGetNewSemKeyAndNum(IPCKey *key, int *semNum);
 static void ProcFreeSem(IpcSemaphoreKey semKey, int semNum);
-#if defined(PORTNAME_linux)
-extern int HandleDeadLock(int);
-#else
-extern int HandleDeadLock(void);
-#endif
 /*
  * InitProcGlobal -
  *    initializes the global process table. We put it here so that
@@ -637,12 +623,8 @@ ProcAddLock(SHM_QUEUE *elem)
  * up my semaphore.
  * --------------------
  */
-int
-#if defined(PORTNAME_linux)
-HandleDeadLock(int i)
-#else
-HandleDeadLock()
-#endif
+void
+HandleDeadLock(int sig)
 {
     LOCK *lock;
     int size;
@@ -662,7 +644,7 @@ HandleDeadLock()
     if (IpcSemaphoreGetCount(MyProc->sem.semId, MyProc->sem.semNum) == 
 	IpcSemaphoreDefaultStartValue) {
 	UnlockLockTable();
-	return 1;
+	return;
     }
     
     /*
@@ -679,7 +661,7 @@ HandleDeadLock()
     if (MyProc->links.prev == INVALID_OFFSET ||
 	MyProc->links.next == INVALID_OFFSET) {
 	UnlockLockTable();
-	return(1);
+	return;
     }
     
     lock = MyProc->waitLock;
@@ -716,7 +698,7 @@ HandleDeadLock()
     UnlockLockTable();
     
     elog(NOTICE, "Timeout -- possible deadlock");
-    return 0;
+    return;
 }
 
 void
